package com.muyu.data.processing.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.data.processing.domain.BasicData;
import com.muyu.data.processing.domain.IotDbData;
import com.muyu.data.processing.service.DataProcessingService;

import javax.annotation.Resource;

import org.springframework.web.bind.annotation.*;
import lombok.extern.slf4j.Slf4j;

import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * 数据处理控制层
 *
 * @Author: 胡杨
 * @Name: DataProcessing
 * @Description: 数据处理控制层
 * @CreatedDate: 2024/9/28 下午3:53
 * @FilePath: com.muyu.data.processing.controller
 */

@Slf4j
@RestController
@RequestMapping("/DataProcessing")
public class DataProcessingController {
    @Resource
    private DataProcessingService service;

    /**
     * 查看数据库有多少组
     *
     * @return
     */
    @GetMapping("/selectStorageGroup")
    public Result selectStorageGroup() {
        List<String> v = service.selectStorageGroup();if (v.size() > 0) {v.forEach(x -> {
            System.out.println("group------------------" + x.toString());
        });
            return Result.success(v);
        } else {
            return Result.error(false);
        }
    }

    @GetMapping("/selectCarData")
    public Result selectCarData(@RequestParam("vin") String vin) {
//        String firmCode = SecurityUtils.getSaasKey();
        String firmCode = "firm01";
        return Result.success(service.selectCarData(firmCode,vin));
    }

    @PostMapping("/addCarData")
    public Result addCarData(@RequestBody IotDbData data) {
        HashMap<String, BasicData> hashMap = new HashMap<>();
        hashMap.put("timestamp", BasicData
                .builder()
                .key("timestamp")
                .label("时间戳")
                .value(String.valueOf(data.getTimestamp()))
                .type("string")
                .build());
        hashMap.put("vin", BasicData
                .builder()
                .key("vin")
                .label("VIN码")
                .value(data.getVin())
                .type("string")
                .build());
        hashMap.put("latitude", BasicData
                .builder()
                .key("latitude")
                .label("纬度")
                .value(data.getLatitude())
                .type("long")
                .build());
        hashMap.put("longitude", BasicData
                .builder()
                .key("longitude")
                .label("经度")
                .value(data.getLongitude())
                .type("long")
                .build());
        hashMap.put("firmCode", BasicData
                .builder()
                .key("firmCode")
                .label("企业编码")
                .value("firm01")
                .type("string")
                .build());
        return Result.success(service.addCarData(hashMap));
    }


}
