package com.muyu.data.processing.service.impl;


import javax.annotation.Resource;

import com.muyu.common.iotdb.config.IotDBSessionConfig;
import com.muyu.data.processing.domain.CarData;
import com.muyu.data.processing.domain.IotDbData;
import com.muyu.data.processing.domain.BasicData;
import org.apache.iotdb.isession.SessionDataSet;
import org.apache.iotdb.isession.pool.SessionDataSetWrapper;
import org.apache.iotdb.rpc.IoTDBConnectionException;
import org.apache.iotdb.rpc.StatementExecutionException;
import org.apache.iotdb.session.pool.SessionPool;
import org.apache.iotdb.tsfile.read.common.Field;
import org.apache.iotdb.tsfile.read.common.RowRecord;
import org.springframework.stereotype.Service;
import lombok.extern.slf4j.Slf4j;
import com.muyu.data.processing.mapper.DataProcessingMapper;
import com.muyu.data.processing.service.DataProcessingService;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 数据处理实现层
 *
 * @Author: 胡杨
 * @Name: DataProcessing
 * @Description: 数据处理实现层
 * @CreatedDate: 2024/9/28 下午3:52
 * @FilePath: com.muyu.data.processing.server.impl
 */

@Slf4j
@Service
public class DataProcessingServiceImpl implements DataProcessingService {
    @Resource
    private DataProcessingMapper mapper;
    @Resource
    private SessionPool sessionPool;


    @Override
    public List<String> selectStorageGroup() {
        return mapper.selectStorageGroup();
    }

    @Override
    public void strategyCheck(List<BasicData> dataList) {
        HashMap<String, BasicData> kafkaDataHashMap = new HashMap<>();
        dataList.forEach(data -> kafkaDataHashMap.put(data.getKey(), data));
//        Result<String[]> result = rootStrategy.applyStrategy(kafkaDataHashMap);
//        String[] data = result.getData();
//        insIotDbData(data[0],data[1]);
        IotDbData build = IotDbData.builder()
                .vin(kafkaDataHashMap.get("vin").getValue())
                .timestamp(Long.parseLong(kafkaDataHashMap.get("timestamp").getValue()))
                .latitude(kafkaDataHashMap.get("latitude").getValue())
                .longitude(kafkaDataHashMap.get("longitude").getValue())
                .build();
        mapper.insIotDbDataVo(build);
//        dataList.forEach(KafkaData::setValueClass);
//        mapper.strategyCheck(dataList);
    }

    @Override
    public Integer insIotDbData(String key, String value) {
        return mapper.insIotDbData(key, value);
    }

    @Override
    public List<CarData> selectCarData(String firmCode, String vin) {
        ArrayList<CarData> carDataList = new ArrayList<>();
        String sql = "select * from root.one."+firmCode+"."+vin;
        try {
            SessionDataSetWrapper dataSetWrapper = sessionPool.executeQueryStatement(sql);
            List<String> columnNames = dataSetWrapper.getColumnNames();
            while (dataSetWrapper.hasNext()){
                RowRecord next = dataSetWrapper.next();
                CarData data = getCarData(vin, next, columnNames);
                carDataList.add(data);
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        return carDataList;
    }

    @Override
    public Object addCarData(HashMap<String, BasicData> hashMap) {
//        StringBuilder sql = new StringBuilder("insert into root.one.");
//        sql.append(hashMap.get("firmCode").getValue())
//                .append(".")
//                .append(hashMap.get("vin").getValue())
//                .append("(");
//        hashMap.remove("firmCode");
//        hashMap.remove("vin");
//        StringBuilder keys = new StringBuilder();
//        StringBuilder values = new StringBuilder();
//        hashMap.keySet().forEach(key -> {
//            if (hashMap.get(key) != null) {
//                keys.append(key).append(",");
//                if ("String".equals(hashMap.get(key).getType())) {
//                    values.append("'")
//                            .append(hashMap.get(key).getValue())
//                            .append("'")
//                            .append(",");
//                }else {
//                    values.append(hashMap.get(key).getValue())
//                            .append(",");
//                }
//            }
//        });
//        sql.append(keys.substring(0, keys.length() - 1))
//                .append(") values (")
//                .append(values.substring(0, values.length() - 1))
//                .append(")");
//        try {
//            sessionPool.executeNonQueryStatement(sql.toString());
//        } catch (StatementExecutionException e) {
//            throw new RuntimeException(e);
//        } catch (IoTDBConnectionException e) {
//            throw new RuntimeException(e);
//        }
//        log.info("成功执行sql语句: [{}]", sql);
//        return sql;
        return null;
    }

    private static CarData getCarData(String vin, RowRecord next, List<String> columnNames) {
        List<Field> fields = next.getFields();
        CarData data = new CarData();
        data.setVin(vin);
        data.setTimestamp(next.getTimestamp());
        for (int i = 0; i < columnNames.size(); i++) {
            if (columnNames.get(i).contains("latitude")) {
                data.setLatitude(fields.get(i-1).getStringValue());
            }else if (columnNames.get(i).contains("longitude")) {
                data.setLongitude(fields.get(i-1).getStringValue());
            }
        }
        return data;
    }


}
